raytraverse.sky
==========================================================

skycalc
---------------------------------

.. automodule:: raytraverse.sky.skycalc
    :members:
    :undoc-members:
    :show-inheritance:

SkyData
---------------------------------

.. autoclass:: raytraverse.sky.SkyData
    :members:
    :undoc-members:
    :show-inheritance:
